# created 5/9/2011 - Jim Lemon
 importFrom("grDevices", "boxplot.stats", "col2rgb", "colors",
    "dev.cur", "dev.list", "dev.size", "gray", "heat.colors",
    "palette", "rainbow", "rgb", "trans3d", "xy.coords")
 importFrom("graphics", "abline", "arrows", "axTicks", "axis",
    "axis.POSIXct", "barplot", "barplot.default", "box",
    "boxplot", "clip", "hist", "hist.default", "layout",
    "legend", "lines", "locator", "matplot", "mtext", "par",
    "persp", "plot", "plot.new", "plot.window", "points",
    "polygon", "rect", "segments", "strheight",
    "strwidth", "symbols", "text", "title", "xinch", "yinch")
 importFrom("stats", "aggregate", "approx", "as.formula",
    "complete.cases", "cor", "density", "dist", "model.frame",
    "na.omit", "bw.nrd0", "qnorm", "rnorm", "sd", "t.test", "terms")
 importFrom("utils", "combn", "modifyList")
export(
 ablineclip,
 addtable2plot,
 add.ps,
 arctext,
 axis.break,
 axis.mult,
 barlabels,
 barNest,
 barp,
 battleship.plot,
 bin.wind.records,
 binciW,
 binciWl,
 binciWu,
 box.heresy,
 boxed.labels,
 brkdn.plot,
 brkdnNest,
 bumpchart,
 categoryReshape,
 centipede.plot,
 clean.args,
 clock24.plot,
 clplot,
 cluster.overplot,
 clustered.dotplots,
 color.axis,
 color.gradient,
 color.id,
 color.legend,
 color.scale,
 color.scale.lines,
 color2D.matplot,
 corner.label,
 count.overplot,
 cylindrect,
 dendroPlot,
 densityGrid,
 diamondplot,
 dispersion,
 dotplot.mtb,
 draw.arc,
 draw.circle,
 draw.ellipse,
 draw.radial.line,
 draw.tilted.sector,
 drawNestedBars,
 drawSectorAnnulus,
 ehplot,
 election,
 emptyspace,
 fan.plot,
 feather.plot,
 fill.corner,
 find_max_cell,
 floating.pie,
 fullaxis,
 gantt.chart,
 gap_barp,
 gap.barplot,
 gap.boxplot,
 gap.plot,
 get.breaks,
 get.gantt.info,
 get.segs,
 get.soil.texture,
 get.tablepos,
 get.triprop,
 getFigCtr,
 getIntersectList,
 getMarginWidth,
 getYmult,
 gradient.rect,
 hexagon,
 histStack,
 intersectDiagram,
 jiggle,
 joyPlot,
 kiteChart,
 labbePlot,
 ladderplot,
 ladderplot.default,
 legendg,
 lengthKey,
 makeDensityMatrix,
 makeIntersectList,
 maxEmptyRect,
 mtext3d,
 multhist,
 multivari,
 multsymbolbox,
 oz.windrose,
 oz.windrose.legend,
 p2p_arrows,
 panes,
 pasteCols,
 paxis3d,
 perspx,
 pie.labels,
 pie3D,
 pie3D.labels,
 placeLabels,
 plot_bg,
 plotCI,
 plotH,
 polar.plot,
 polygon.shadow,
 propbrk,
 psegments3d,
 ptext3d,
 pyramid.plot,
 radial.grid,
 radial.pie,
 radial.plot,
 radial.plot.labels,
 radialtext,
 raw.means.plot,
 raw.means.plot2,
 rectFill,
 remove.args,
 rescale,
 revaxis,
 ruginv,
 seats,
 size_n_color,
 sizeplot,
 sizetree,
 sliceArray,
 smoothColors,
 soil.texture,
 soil.texture.uk,
 spread.labels,
 spreadout,
 stackpoly,
 staircase.plot,
 staircasePlot,
 starPie,
 staxlab,
 std.error,
 sumbrk,
 symbolbarplot,
 symbolbox,
 tab.title,
 taylor.diagram,
 textbox,
 thigmophobe,
 thigmophobe.labels,
 triax.abline,
 triax.fill,
 triax.frame,
 triax.plot,
 triax.points,
 tsxpos,
 twoord.plot,
 twoord.stackplot,
 valid.n,
 vectorField,
 violin_plot,
 weighted.hist,
 zoomInPlot
)
# methods
S3method(print,brklist)
S3method(histStack,default)
S3method(histStack,formula)
S3method(plotH,formula)
S3method(plotH,default)
S3method(ladderplot,default)
