
<!-- README.md is generated from README.Rmd. Please edit that file -->

# plotrix

<!-- badges: start -->

[![R-CMD-check](https://github.com/plotrix/plotrix/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/plotrix/plotrix/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

`plotrix` is an `R` package that provides many plotting, labeling, and
axis & color scaling functions.

## Installation

You can install the current release of `plotrix` from CRAN with:

``` r
install.packages("plotrix")
```

You can install the development version of plotrix from
[GitHub](https://github.com/) with:

``` r
# install.packages("devtools")
devtools::install_github("plotrix/plotrix")
```

## Authors

The original author and maintainer of `plotrix`, Jim Lemon, passed away
in September 2023.

Currently it is being maintained by Duncan Murdoch. Please submit bug
reports to <https://github.com/plotrix/plotrix/issues>.

Other contributors include:

Ben Bolker \[ctb\],  
Sander Oom \[ctb\],  
Eduardo Klein \[ctb\],  
Barry Rowlingson \[ctb\],  
Hadley Wickham \[ctb\],  
Anupam Tyagi \[ctb\],  
Olivier Eterradossi \[ctb\],  
Gabor Grothendieck \[ctb\],  
Michael Toews \[ctb\],  
John Kane \[ctb\],  
Rolf Turner \[ctb\],  
Carl Witthoft \[ctb\],  
Julian Stander \[ctb\],  
Thomas Petzoldt \[ctb\],  
Remko Duursma \[ctb\],  
Elisa Biancotto \[ctb\],  
Ofir Levy \[ctb\],  
Christophe Dutang \[ctb\],  
Peter Solymos \[ctb\],  
Robby Engelmann \[ctb\],  
Michael Hecker \[ctb\],  
Felix Steinbeck \[ctb\],  
Hans Borchers \[ctb\],  
Henrik Singmann \[ctb\],  
Ted Toal \[ctb\],  
Derek Ogle \[ctb\],  
Darshan Baral \[ctb\],  
Ulrike Groemping \[ctb\],  
Bill Venables \[ctb\],  
The CRAN Team \[ctb\].
