\name{death_reg}
\alias{death_reg}
\title{Death registrations from 1996 to 2010}
\description{
 Death registrations for underlying cause of death as ICD-10 chapters for 1996
 to 2010.
}
\usage{
 data(death_reg)
}
\keyword{misc}
